@@ -4,6 +4,9 @@ from typing import Optional
 from .CompleteFinancingPaymentMethodSpecificInput import (
     CompleteFinancingPaymentMethodSpecificInput,
 )
+from .CompleteRedirectPaymentMethodSpecificInput import (
+    CompleteRedirectPaymentMethodSpecificInput,
+)
 from .CustomerDevice import CustomerDevice
 from .Order import Order
 
@@ -13,5 +16,8 @@ class CompletePaymentRequest:
     financingPaymentMethodSpecificInput: Optional[
         CompleteFinancingPaymentMethodSpecificInput
     ] = None
+    redirectPaymentMethodSpecificInput: Optional[
+        CompleteRedirectPaymentMethodSpecificInput
+    ] = None
     order: Optional[Order] = None
     device: Optional[CustomerDevice] = None
